@@ -429,6 +429,18 @@ class JuicerHic(RegionMatrixContainer):
 
         return chromosome_lengths
 
+    def _chromosome_bins(self, *args, **kwargs):
+        chromosome_lengths = self.chromosome_lengths
+        bin_size = self.bin_size
+        current_chromosome_start_bin = 0
+        chromosome_bins = {}
+        for chromosome in self.chromosomes():
+            chromosome_length = chromosome_lengths[chromosome]
+            end = int(np.ceil(chromosome_length / bin_size))
+            chromosome_bins[chromosome] = [current_chromosome_start_bin, current_chromosome_start_bin + end]
+            current_chromosome_start_bin += end
+        return chromosome_bins
+
     def _all_chromosomes(self):
         with open(self._hic_file, 'rb') as req:
             JuicerHic._skip_to_chromosome_lengths(req)
@@ -619,18 +631,34 @@ class JuicerHic(RegionMatrixContainer):
             return JuicerHic._expected_value_vectors_from_pos(req, normalisation=normalisation)
 
     def expected_values(self, selected_chromosome=None, norm=True, *args, **kwargs):
+        def _fill_norm_vector(v, n, fill):
+            if len(v) < n:
+                v = np.append(v, [fill for _ in range(n - len(v))])
+            return v
+
+        cb = self.chromosome_bins
         if selected_chromosome is not None:
             if norm:
-                return self.expected_value_vector(selected_chromosome, self._normalisation)
+                expected_chromosome = self.expected_value_vector(selected_chromosome, self._normalisation)
             else:
-                return self.expected_value_vector(selected_chromosome, 'NONE')
+                expected_chromosome = self.expected_value_vector(selected_chromosome, 'NONE')
+
+            chromosome_size_in_bins = cb[selected_chromosome][1] - cb[selected_chromosome][0]
+            expected_chromosome = _fill_norm_vector(expected_chromosome, chromosome_size_in_bins, 0)
+
+            return expected_chromosome
 
         intra_expected = dict()
         for chromosome in self.chromosomes():
             if norm:
-                intra_expected[chromosome] = self.expected_value_vector(chromosome, self._normalisation)
+                expected_chromosome = self.expected_value_vector(chromosome, self._normalisation)
             else:
-                intra_expected[chromosome] = self.expected_value_vector(chromosome, 'NONE')
+                expected_chromosome = self.expected_value_vector(chromosome, 'NONE')
+
+            chromosome_size_in_bins = cb[chromosome][1] - cb[chromosome][0]
+            expected_chromosome = _fill_norm_vector(expected_chromosome, chromosome_size_in_bins, 0)
+
+            intra_expected[chromosome] = expected_chromosome
 
         return None, intra_expected, None
 
@@ -777,7 +805,7 @@ class JuicerHic(RegionMatrixContainer):
 
         cl = self.chromosome_lengths[region.chromosome]
         norm = self.normalisation_vector(region.chromosome)
-        for i, start in enumerate(range(subset_start, region.end, self._resolution)):
+        for i, start in enumerate(range(subset_start, int(region.end), self._resolution)):
             end = min(start + self._resolution - 1, cl, region.end)
             bias_ix = int(start / self._resolution)
 
@@ -794,8 +822,8 @@ class JuicerHic(RegionMatrixContainer):
             if np.isnan(bias):
                 bias = 1.0
 
-            r = GenomicRegion(chromosome=region.chromosome, start=start,
-                              end=end, bias=bias, valid=valid,
+            r = GenomicRegion(chromosome=region.chromosome, start=int(start),
+                              end=int(end), bias=bias, valid=valid,
                               ix=int(subset_ix + i))
             yield r
 
